@@ -26,6 +26,12 @@ class SSPOR(BaseEstimator):
     One can then select the top k sensors and take future measurements at
     that limited set of locations.
 
+    The overall time complexity of fitting a :class:`SSPOR` object is
+    :code:`O(n_basis_modes * n_input_features * n_input_features)`
+    plus the cost for fitting the basis. Different bases have different
+    complexities. The space complexity is
+    :code:`O(n_basis_modes * n_input_features)`.
+
     Parameters
     ----------
     basis: basis object, optional (default :class:`pysensors.basis.Identity`)
@@ -131,9 +137,11 @@ class SSPOR(BaseEstimator):
         else:
             x = validate_input(x)
 
-            with warnings.catch_warnings():
-                action = "ignore" if quiet else "default"
-                warnings.filterwarnings(action, category=UserWarning)
+            if quiet:
+                with warnings.catch_warnings():
+                    warnings.filterwarnings("ignore", category=UserWarning)
+                    self.basis.fit(x)
+            else:
                 self.basis.fit(x)
 
         # Get matrix representation of basis
@@ -307,7 +315,7 @@ class SSPOR(BaseEstimator):
         """
         self.set_number_of_sensors(n_sensors)
 
-    def update_n_basis_modes(self, n_basis_modes, x=None):
+    def update_n_basis_modes(self, n_basis_modes, x=None, quiet=False):
         """
         Re-fit the :class:`SSPOR` object using a different value of
         ``n_basis_modes``.
@@ -328,6 +336,9 @@ class SSPOR(BaseEstimator):
         x: numpy array, shape (n_examples, n_features), optional (default None)
             Only used if ``n_basis_modes`` exceeds the number of available
             basis modes for the already fit basis.
+
+        quiet: boolean, optional (default False)
+            Whether or not to suppress warnings during refitting.
         """
         if not isinstance(n_basis_modes, INT_DTYPES) or n_basis_modes <= 0:
             raise ValueError("n_basis_modes must be a positive integer")
@@ -338,7 +349,7 @@ class SSPOR(BaseEstimator):
             and n_basis_modes <= self.basis.n_basis_modes
         ):
             self.n_basis_modes = n_basis_modes
-            self.fit(x, prefit_basis=True)
+            self.fit(x, prefit_basis=True, quiet=quiet)
 
         elif x is None:
             raise ValueError(
@@ -351,7 +362,7 @@ class SSPOR(BaseEstimator):
         else:
             self.n_basis_modes = n_basis_modes
             self.basis.n_basis_modes = n_basis_modes
-            self.fit(x, prefit_basis=False)
+            self.fit(x, prefit_basis=False, quiet=quiet)
 
     def score(self, x, y=None, score_function=None, score_kws={}, solve_kws={}):
         """
